@@ -2,6 +2,6 @@ try:
     from psycopg2cffi import compat
 except ImportError:
     pass
-else:
+else:  # pragma: no cover
     compat.register()
     del compat
