@@ -3,7 +3,6 @@ import datetime
 import decimal
 import json
 import logging
-
 import sqlalchemy.orm
 
 
@@ -51,12 +50,14 @@ def encode(o):
             return encoder(o)
     return json._default_encoder._default_orig(o)
 
+
 try:
     import pyramid.renderers
     has_pyramid = True
-except ImportError:
+except ImportError:  # pragma: no cover
     has_pyramid = False
 
+
 if has_pyramid:
     def json_renderer_factory(*args, **kw):
         renderer = pyramid.renderers.JSON(*args, **kw)
